==> flexiconc-0.1.6-py3-none-any.whl: flexiconc/algorithms/select_slot.py <==
def select_slot(conc, **args):
    """
    Selects the appropriate offset column based on the slot_id.

    Args are dynamically validated and extracted from the schema.

    Parameters:
    - conc (Union[Concordance, ConcordanceSubset]): The concordance or subset of data.
    - args (dict): Arguments include:
        - slot_id (int): The slot identifier used to generate the offset column name.

    Returns:
    - dict: A dictionary containing:
        - "slot_to_use": The slot ID being selected.
        - "selected_lines": A list of all line IDs in the concordance.
        - "line_count": The total number of lines.
    """

    # Metadata for the algorithm
    select_slot._algorithm_metadata = {
        "name": "Select Slot",
        "description": "Selects the slot to work with.",
        "algorithm_type": "selection",
        "conditions": {"concordance": {"has_slots": True}},
        "args_schema": {
            "type": "object",
            "properties": {
                "slot_id": {
                    "type": "integer",
                    "description": "The slot identifier to select.",
                    "x-eval": "dict(enum=list(set(conc.matches['slot'])))"
                }
            },
            "required": ["slot_id"]
        }
    }

    # Extract arguments
    slot_id = args["slot_id"]

    # Retrieve all line IDs from the concordance metadata
    line_ids = conc.metadata.index.tolist()

    return {
        "slot_to_use": slot_id,
        "selected_lines": line_ids,
    }

==> flexiconc-0.1.9-py3-none-any.whl: flexiconc/algorithms/select_slot.py <==
def select_slot(conc, **args):
    """
    Selects the appropriate offset column based on the slot_id.

    Args are dynamically validated and extracted from the schema.

    Parameters:
    - conc (Union[Concordance, ConcordanceSubset]): The concordance or subset of data.
    - args (dict): Arguments include:
        - slot_id (int): The slot identifier used to generate the offset column name.

    Returns:
    - dict: A dictionary containing:
        - "slot_to_use": The slot ID being selected.
        - "selected_lines": A list of all line IDs in the concordance.
        - "line_count": The total number of lines.
    """

    # Metadata for the algorithm
    select_slot._algorithm_metadata = {
        "name": "Select Slot",
        "description": "Selects the slot to work with.",
        "algorithm_type": "selecting",
        "conditions": {"concordance": {"has_slots": True}},
        "args_schema": {
            "type": "object",
            "properties": {
                "slot_id": {
                    "type": "integer",
                    "description": "The slot identifier to select.",
                    "x-eval": "dict(enum=list(set(conc.matches['slot'])))"
                }
            },
            "required": ["slot_id"]
        }
    }

    # Extract arguments
    slot_id = args["slot_id"]

    # Retrieve all line IDs from the concordance metadata
    line_ids = conc.metadata.index.tolist()

    return {
        "slot_to_use": slot_id,
        "selected_lines": line_ids,
    }
